import { Injectable } from '@angular/core';
import {
  HttpRequest,
  HttpHandler,
  HttpEvent,
  HttpInterceptor,
  HttpResponse
} from '@angular/common/http';
import { Observable, tap } from 'rxjs';
import { AuthConfigConsts, tokenNotExpired } from "../../mine/auth.jwt";

@Injectable()
export class AuthInterceptor implements HttpInterceptor {

  constructor() {}

  intercept(req: HttpRequest<unknown>, next: HttpHandler): Observable<HttpEvent<unknown>> {
    const token = sessionStorage.getItem('token');
    console.log('当前 token:', token);
    console.log('请求:', req.url);

    let authHeader = req.headers;
    if (token != null && tokenNotExpired()) {
      const bearer = AuthConfigConsts.HEADER_PREFIX_BEARER + token;
      authHeader = authHeader.set(AuthConfigConsts.DEFAULT_HEADER_NAME, bearer);
    }

    const authReq = req.clone({headers: authHeader});

    return next.handle(authReq).pipe(
      tap((event) => {
        // 如果是 HTTP 响应
        if (event instanceof HttpResponse) {
          // 从响应头中获取 Authorization token
          const authToken = event.headers.get('Authorization');

          if (authToken && (!token || token !== authToken.replace(AuthConfigConsts.HEADER_PREFIX_BEARER, ''))) {
            console.log('从响应中获取到新的 token:', authToken);
            // 去掉 Bearer 前缀
            const newToken = authToken.replace(AuthConfigConsts.HEADER_PREFIX_BEARER, '');
            // 保存到 sessionStorage
            sessionStorage.setItem('token', newToken);
          }
        }
      })
    );
  }

  private isGuestToken(token: string): boolean {
    try {
      // 解析 JWT token
      const payload = JSON.parse(atob(token.split('.')[1]));
      const isGuest = !payload.phone;
      console.log('Token payload:', payload); // 添加日志
      return isGuest;
    } catch (error) {
      console.error('Error parsing token:', error); // 添加错误日志
      return true; // 解析失败时默认为游客
    }
  }
}
