import { Component, OnInit, AfterViewInit } from '@angular/core';
import { NavController } from '@ionic/angular';
import { Router } from '@angular/router';
import { ModalController } from '@ionic/angular';
import { Article } from "../../shared/model/article";
import { ImagePreviewComponent } from "../component/image-preview/image-preview.component";

@Component({
  selector: 'app-article-detail',
  templateUrl: './article-detail.page.html',
  styleUrls: ['./article-detail.page.scss'],
  standalone: false,
})
export class ArticleDetailPage implements OnInit, AfterViewInit {
  article?: Article;
  weekday = "";

  constructor(
    private navCtrl: NavController,
    private router: Router,
    private modalCtrl: ModalController
  ) {
    // 获取导航传递的数据
    const navigation = this.router.getCurrentNavigation();
    const article = navigation?.extras?.state?.['article'];
    if (article) {
      this.article = article;
      this.addWeekday();
    }
  }

  ngOnInit() {}

  ngAfterViewInit() {
    // 在内容渲染后添加图片点击事件
    this.setupImageClickHandlers();
  }

  ionViewDidEnter() {
    // 页面完全进入后再次检查并添加图片点击事件
    this.setupImageClickHandlers();
  }

  ionViewWillEnter() {
    // 如果没有获取到文章数据，返回上一页
    if (!this.article) {
      this.navCtrl.back();
    }
  }

  // 添加星期几
  private addWeekday() {
    if (this.article) {
      const date = new Date();
      const weekdays = ['星期日', '星期一', '星期二', '星期三', '星期四', '星期五', '星期六'];
      this.weekday = weekdays[date.getDay()];
    }
  }

  // 设置图片点击事件处理
  private setupImageClickHandlers() {
    const contentElement = document.querySelector('.article-content');
    if (contentElement) {
      const images = contentElement.getElementsByTagName('img');
      Array.from(images).forEach(img => {
        img.style.cursor = 'pointer';
        img.onclick = (e: Event) => {
          const target = e.target as HTMLImageElement;
          this.showImagePreview(target.src);
        };
      });
    }
  }

  // 显示图片预览
  private showImagePreview(imageUrl: string) {
    this.modalCtrl.create({
      component: ImagePreviewComponent,
      componentProps: {
        imageUrl
      },
      cssClass: 'image-preview-modal'
    }).then(modal => {
      modal.present();
    });
  }
}