import {ChangeDetectorRef, Component, Input, OnInit} from '@angular/core';
import {Article} from "../../../shared/model/article";
import {InfiniteScrollCustomEvent} from "@ionic/angular";
import {HomeService} from "../../home.service";

@Component({
  selector: 'app-article-content',
  templateUrl: './article-content.component.html',
  styleUrls: ['./article-content.component.scss'],
  standalone:false,
})
export class ArticleContentComponent  implements OnInit {
  searchParams: { [param: string]: any } = {
    page: 0,
    size: 10,
  };
  hasMore: boolean = true;
  @Input() className:string = ""
  data:Article[] = []
  currentSelect = "new"
  constructor(private homeService:HomeService,
              private cdr:ChangeDetectorRef) { }

  ngOnInit() {
    this.getData();
  }
  ionChange(e:any){
    this.searchParams['page'] = 0
    this.data = []
    this.currentSelect = e.detail.value
    this.getData()
  }

  getData() {
    switch (this.currentSelect){
      case "new":
        return this.getNewData()
      case "unlock":
        return this.getUnLockData()
      case "free":
        return this.getFreeData()
    }

  }
  getNewData() {
    this.homeService.list(this.searchParams).subscribe(res=>{
      if(res.items.length > 0) {
        this.data = this.data.concat(res.items)
        this.searchParams['page'] = this.searchParams['page']+1;
        this.hasMore = res.items.length === this.searchParams['size'];
        this.cdr.detectChanges();
      }
    })
  }
  getUnLockData() {
    this.homeService.unlockList(this.searchParams).subscribe(res=>{
      if(res.items.length > 0) {
        this.data = this.data.concat(res.items)
        this.searchParams['page'] = this.searchParams['page']+1;
        this.hasMore = res.items.length === this.searchParams['size'];
        this.cdr.detectChanges();
      }
    })
  }
  getFreeData() {
    this.homeService.freeList(this.searchParams).subscribe(res=>{
      if(res.items.length > 0) {
        this.data = this.data.concat(res.items)
        this.searchParams['page'] = this.searchParams['page']+1;
        this.hasMore = res.items.length === this.searchParams['size'];
        this.cdr.detectChanges();
      }
    })
  }

  onIonInfinite(event: InfiniteScrollCustomEvent) {
    if (this.hasMore) {
      this.getData();
      setTimeout(() => {
        event.target.complete();
      }, 1000);
    } else {
      event.target.disabled = true;
    }
  }





}
