import { Component, ViewChild, ElementRef, AfterViewInit } from '@angular/core';
// 导入 Swiper 核心模块和需要的模块
import Swiper from 'swiper';
import { Pagination } from 'swiper/modules';
import {NavController} from "@ionic/angular";

interface IconItem {
  name: string;
  image: string;
  remark:string;
}

@Component({
  selector: 'app-home-icons',
  templateUrl: './home-icons.component.html',
  styleUrls: ['./home-icons.component.scss'],
  standalone: false,
})
export class HomeIconsComponent implements AfterViewInit {
  @ViewChild('swiperContainer') swiperContainer!: ElementRef;
  currentPage = 0;
  private swiper?: Swiper;

  icons: IconItem[] = [
    { name: '盘中宝', image: 'pzb.png', remark: "" },
    { name: '风口研报', image: 'fkyb.png', remark:""},
    { name: '狙击龙虎榜', image: 'jjlhb.png',remark:"rx.png" },
    { name: '电报解读', image: 'dbjd.png', remark:""},
    { name: '财联社早知道', image: 'clzzd.png', remark:""},
    { name: '研选', image: 'yx.png', remark:""},
    { name: '金牌纪要库', image: 'jpjyk.png', remark: "rd.png" },
    { name: '九点特供', image: 'jdtg.png',remark:"bd.png" },
    { name: '公告全知道', image: 'ggqzd.png', remark:""}
  ];
  constructor(private navCtrl: NavController) {
  }
  get firstPageIcons(): IconItem[] {
    return this.icons.slice(0, 8);
  }

  get lastIcon(): IconItem {
    return this.icons[8];
  }

  ngAfterViewInit() {
    // 注册 Swiper 模块
    Swiper.use([Pagination]);

    this.swiper = new Swiper(this.swiperContainer.nativeElement, {
      modules: [Pagination],
      slidesPerView: 1,
      spaceBetween: 0,
      speed: 300,
      touchRatio: 1,
      touchAngle: 45,
      touchStartPreventDefault: false,
      pagination: {
        el: '.swiper-pagination',
        clickable: true
      },
      on: {
        slideChange: () => {
          this.currentPage = this.swiper?.activeIndex || 0;
        }
      }
    });
  }
  columnDetail(name:string){
    this.navCtrl.navigateForward('/home/special-column', {
      state:{name:name}
    });
  }

  slideTo(index: number) {
    this.swiper?.slideTo(index);
  }

  ngOnDestroy() {
    if (this.swiper) {
      this.swiper.destroy();
    }
  }
}
