import { Component, OnInit, OnDestroy } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { ToastController } from '@ionic/angular';
import {getUser, MineService} from './mine.service';
import {delay} from "rxjs";
import { Router } from '@angular/router';
import {UserInfo} from "../shared/model/user";


@Component({
  selector: 'app-mine',
  templateUrl: './mine.page.html',
  styleUrls: ['./mine.page.scss'],
  standalone:false
})
export class MinePage implements OnInit, OnDestroy {
  isLoggedIn = false;
  userInfo: UserInfo | null = null;
  loginType: 'sms' | 'password' = 'sms';
  showPassword = false;
  countdown = 0;
  canSendCode = false;
  captchaImage: string = '';

  constructor(
    private mineService: MineService,
    private fb: FormBuilder,
    private router: Router,
    private toastCtrl: ToastController,

  ) {
    getUser().subscribe(res=>{
      console.log(res)
      if(res.username == "") {
        this.isLoggedIn = false;
        this.router.navigate(['/mine/login'])
      } else {
        this.isLoggedIn = true;
        this.getUserInfo()
      }
    })
  }

  ngOnInit() {
    this.checkLoginStatus();

  }

  ngOnDestroy() {
    if (this.captchaImage) {
      URL.revokeObjectURL(this.captchaImage);
    }
  }

  checkLoginStatus() {
    const token = localStorage.getItem('token');
    if (token) {
      this.isLoggedIn = true;
      this.getUserInfo();
    }
  }



  private getUserInfo() {
    this.mineService.getUserInfo().subscribe({
      next: (info) => {
        this.userInfo = info;
        localStorage.setItem("giftCount",info.giftCount)
      },
      error: (error) => {
        this.showToast(error?.message || '获取用户信息失败', 'danger');
        this.logout();
      }
    });
  }

  private startCountdown() {
    this.countdown = 60;
    const timer = setInterval(() => {
      this.countdown--;
      if (this.countdown === 0) {
        clearInterval(timer);
      }
    }, 1000);
  }

  togglePassword() {
    this.showPassword = !this.showPassword;
  }

  logout() {
    localStorage.removeItem('token');
    this.isLoggedIn = false;
    this.userInfo = null;
    this.showToast('已退出登录', 'success');
  }

  private showToast(message: string, color: 'success' | 'danger' = 'success') {
    this.toastCtrl.create({
      message,
      duration: 2000,
      color,
      position: 'top',
      cssClass: 'ion-text-center'
    }).then(toast => toast.present());
  }
}
