import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import {EMPTY, Observable, of} from 'rxjs';
import {JwtHelper} from "./auth.jwt";
import {UserDetail, UserInfo} from "../shared/model/user";
import { environment } from '../../environments/environment';
import { switchMap, catchError } from 'rxjs/operators';
import { ModalController } from '@ionic/angular';
import {SlideData} from "go-captcha-angular";





export interface LoginResponse {
  token: string;
}

@Injectable({
  providedIn: 'root'
})
export class MineService {
  private apiUrl = environment.apiUrl;

  constructor(private http: HttpClient, private modalController: ModalController) {}

  // 获取滑动验证码
  getSlideCaptcha(phone: string): Observable<SlideData> {
    return this.http.post<SlideData>('/api/auth/image-captcha',  { phone });
  }

  /**
   * 发送短信验证码
   * @param phone 手机号
   * @returns Observable<void>
   */
  sendSmsCaptcha(phone: string, verifyToken: string): Observable<void> {
    console.log("发送短信验证码，手机号:", phone);
    return this.http.post<void>(`/api/auth/sms-captcha`, {
      phone
    }, {
      headers: { 'Content-Type': 'application/json' }
    }).pipe(
      catchError(error => {
        console.error('发送短信验证码失败:', error);
        throw error;
      })
    );
  }


  passwordLogin(phone: string, password: string, verifyToken: string): Observable<any> {
    return this.http.post(`/api/auth/login-password`, {
      phone,
      password,
      verifyToken
    });
  }


  smsLogin(phone: string, smsCode: string): Observable<any> {
    return this.http.post(`/api/auth/login-captcha`, {
      phone,
      smsCode
    });
  }

  // 获取用户信息
  getUserInfo(): Observable<UserInfo> {
    return this.http.get<UserInfo>('/api/user/profile', );
  }

  verifyImageCaptcha(phone: string, captchaCode: string): Observable<void> {
    return this.http.post<void>('/api/auth/verify-image', { phone, captchaCode }, { withCredentials: true });
  }

  verifySmsCaptcha(phone: string, captchaCode: string): Observable<void> {
    return this.http.post<void>('/api/auth/verify-sms', { phone, captchaCode }, { withCredentials: true });
  }

  sendVerificationCode(phone: string): Observable<void> {
    return this.http.post<void>('/api/auth/sms/code', { phone }, { withCredentials: true });
  }

}

export const getLoggedIn = () => {
  const token: string | null = sessionStorage.getItem('token');
  const jwtHelper = new JwtHelper();
  return of(token != null && !jwtHelper.isTokenExpired(token));
};
export const getUser = (): Observable<UserDetail> => {
  const jwtHelper = new JwtHelper();
  const token = sessionStorage.getItem('token');
  if (token != null) {
    const userObj = jwtHelper.decodeToken(token);
    console.log(userObj)
    return of({
      username: userObj.username,
      guest_id: userObj.guest_id,
    } as UserDetail);
  } else {
    return EMPTY
  }
};
