package reflect

import (
	"errors"
	"reflect"
	"unsafe"
)

// ParseValueByTag can parse source to dest by json tag
// input pointer and pointer
// output some error or nil
func ParseValueByTag(source, dest interface{}) error {
	m := GetJsonTagValue(source)
	to := reflect.TypeOf(dest)
	vo := reflect.ValueOf(dest)
	if to.Kind() != reflect.Pointer {
		return errors.New("the second arg must be a pointer")
	}
	to = to.Elem()
	nf := to.NumField()
	for i := 0; i < nf; i++ {
		t := to.Field(i).Tag.Get("json")
		v, has := m[t]
		if !has {
			continue
		}
		if vo.Elem().CanSet() {
			switch to.Field(i).Type.Kind() {
			case reflect.Int64:
				vo.Elem().Field(i).SetInt(v.(int64))
			case reflect.String:
				vo.Elem().Field(i).SetString(v.(string))
			case reflect.Array:
				vo.Elem().Field(i).SetPointer(unsafe.Pointer(&v))
			}
		}

	}
	return nil
}

// GetJsonTagValue can fetch arg json tag value to a map
// input pointer
// output map
func GetJsonTagValue(arg interface{}) map[string]interface{} {
	to := reflect.TypeOf(arg)
	vo := reflect.ValueOf(arg)
	if to.Kind() == reflect.Pointer {
		to = to.Elem()
		vo = vo.Elem()
	}
	nf := to.NumField()
	r := make(map[string]interface{})
	for i := 0; i < nf; i++ {
		t := to.Field(i).Tag.Get("json")
		if t != "" {
			switch to.Field(i).Type.Kind() {
			case reflect.String:
				v := vo.Field(i).String()
				if v != "" {
					r[t] = v
				}
			case reflect.Int64, reflect.Int32, reflect.Int:
				v := vo.Field(i).Int()
				if v != 0 {
					r[t] = v
				}
			case reflect.Slice, reflect.Array:
				v1 := vo.Field(i).UnsafePointer()
				v := *(*[]string)(v1)
				if len(v) != 0 {
					r[t] = v
				}

			}
		}
	}
	return r
}
